summaryrefslogtreecommitdiffstats
path: root/noatun/library/ksaver.h
diff options
context:
space:
mode:
Diffstat (limited to 'noatun/library/ksaver.h')
-rw-r--r--noatun/library/ksaver.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/noatun/library/ksaver.h b/noatun/library/ksaver.h
index e55b2c0d..91fc4af8 100644
--- a/noatun/library/ksaver.h
+++ b/noatun/library/ksaver.h
@@ -25,10 +25,10 @@
#define KSAVER_H
#include <kurl.h>
-#include <qfile.h>
-#include <qstring.h>
-#include <qtextstream.h>
-#include <qdatastream.h>
+#include <tqfile.h>
+#include <tqstring.h>
+#include <tqtextstream.h>
+#include <tqdatastream.h>
namespace Noatun
{
@@ -42,7 +42,7 @@ class KSaver
public:
/**
* The constructor takes the url and decides the best way to save,
* which will mean using something like KIO::NetAccess or QFile.
*/
KSaver(const KURL &_target);
@@ -69,29 +69,29 @@ public:
* If open or close returns false, there was an error, and error
* returns what the error was, when available.
*/
- QString error(void);
+ TQString error(void);
/**
* file returns a QFile open for writing, which may be for a temporary
* file on the local filesystem.
*
* If this is called before the file is opened, you will crash.
*/
- QFile &file(void);
+ TQFile &file(void);
/**
* You can use this to write out your data.
*
* If this is called before the file is opened, you will crash.
*/
- QTextStream &textStream(void);
+ TQTextStream &textStream(void);
/**
* You can use this to write out your data.
*
* If this is called before the file is opened, you will crash.
*/
- QDataStream &dataStream(void);
+ TQDataStream &dataStream(void);
private:
class KSaverPrivate;
KSaverPrivate *d;
@@ -42,7 +42,7 @@ class KSaver
/**
* The constructor takes the url and decides the best way to save,
- * which will mean using something like KIO::NetAccess or QFile.
+ * which will mean using something like KIO::NetAccess or TQFile.
*/
KSaver(const KURL &_target);
@@ -69,29 +69,29 @@ public:
/**
- * file returns a QFile open for writing, which may be for a temporary
+ * file returns a TQFile open for writing, which may be for a temporary
* file on the local filesystem.
*